@@ -1,7 +1,7 @@
 '''
     This is a module named "nester.py" by Splendour
 '''
-def sortlist (sortedlist, level = 0):
+def sortlist (sortedlist, indent = False, level = 0):
     '''
         This is a function to print all the items in a list.
         "sortedlist" is the target list. It can be a single list,
@@ -10,9 +10,10 @@ def sortlist (sortedlist, level = 0):
             in a list.
     '''
     for listitem in sortedlist:
-            if isinstance(listitem,list):
-                    sortlist(listitem, level + 1)
-            else:
-                    for tab_num in range(level):
-                            print("\t", end = '')
-                    print(listitem)
+        if isinstance(listitem, list):
+            sortlist(listitem, indent, level + 1)
+        else:
+            if indent:
+                for tab_num in range(level):
+                    print("\t", end = '')
+            print(listitem)
